CheckinMediaFile class

Media file returned by the Checkin.com Results API (documents, selfies, OCR images).

uri is typically a pre-signed Picktify proxy URL (https://…/files/proxy/images/….jpeg?t=…&s=…).

Constructors

CheckinMediaFile({String? id, required String kind, String? mediaType, String? uri, String? fileId})
const
CheckinMediaFile.fromJson(Map<String, dynamic> json)
factory

Properties

fileId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
kind String
final
mediaType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited