CheckinOverallResult class

Overall verification decision from the Results API overallResult object.

Constructors

CheckinOverallResult({required String status, List<CheckinResultComment> comments = const [], DateTime? validationDate})
const
CheckinOverallResult.fromJson(Map<String, dynamic> json)
factory

Properties

comments List<CheckinResultComment>
final
hashCode int
The hash code for this object.
no setterinherited
isApproved bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
validationDate DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited